Node-Colored Graphlet Counting
==============================

Usage
-----
   ```
   $ ./node-colored-gdv [Colored Network File GW] [Node Color File] [ [Output File]
   ```

The network file should be in standard GW format. Weights and edge names will be ignored.

  ```
  EXAMPLE.GRAPH
  string
  int
  -1
  5
  |{v1}|
  |{v2}|
  |{v3}|
  |{v4}|
  |{v5}|
  10
  1 2 0 |{1}|
  2 3 0 |{2}|
  3 4 0 |{3}|
  4 1 0 |{4}|
  2 4 0 |{5}|
  5 3 0 |{6}|
  2 5 0 |{7}|
  4 5 0 |{8}|
  1 3 0 |{9}|
  1 5 0 |{10}|
  ```

The node color file should consist of two tab separated columns. The first
column should have the node name as it is in the network file. The second
column should have the nodes color. The colors must be integers, and must be
natural numbers starting at 1. Having a network with only colors 2 and 3 would
be invalid. An example file is shown below:

  ```
  v1  1
  v2  2
  v3  2
  v4  2
  v5  1
  ```

Edge-Colored Graphlet Counting
==============================

Usage
-----
   ```
   $ ./edge-colored-gdv [Colored Network File GW] [Output File]
   ```

The network file should be in standard GW format, except the edge weights
should be replaced by the edge color. The colors must be integers, and must be
natural numbers starting at 1. Having a network with only colors 2 and 3 would
be invalid. An example file is shown below:

  ```
  EXAMPLE.GRAPH
  string
  int
  -1
  5
  |{v1}|
  |{v2}|
  |{v3}|
  |{v4}|
  |{v5}|
  10
  1 2 1 |{1}|
  2 3 2 |{2}|
  3 4 2 |{3}|
  4 1 1 |{3}|
  2 4 2 |{3}|
  5 3 1 |{3}|
  2 5 3 |{3}|
  4 5 3 |{3}|
  1 3 2 |{3}|
  1 5 1 |{3}|
  ```

Interpreting Output
===================
Assume we have the following network file:

  ```
  LEDA.GRAPH
  string
  int
  -1
  3
  |{v1}|
  |{v2}|
  |{v3}|
  3
  1 2 1 |{1}|
  2 3 2 |{2}|
  2 3 1 |{3}|
  ```

An example edge-colored output is shown below:

  ```
  v1 1 0 0 0 0 1 0 0 0 ...
  v2 1 0 1 0 0 0 0 0 1 ...
  v3 0 0 1 0 0 1 0 0 0 ... 
  ```

For simplicity I have only shown the first 9 indices since the rest are 0.
This network has 2 colors, so there will be 3 possible colored graphlets for
each regular graphlet ({1}, {2}, {1,2}). The first three indices correspond to
the colored versions of the first regular orbit (link), indices 4-6 represent
the second orbit (outer nodes on a three node path), and indices 7-9 represent
the third orbit (middle of a three node path). This can be generalized. To find
the orbit from the index (assuming we start counting at 1), take the ceiling
function of the index divided by (2^k) - 1 where k is the total number of
colors.

We can also map each subindex in each orbit (in this case each orbit has three
subindices) to a color set. First, convert the subindex to binary. The binary
representation of each subindex is a bitset for the colors, where the first
color is the least significant bit and the last color is the most significant.
For this example, a subindex of 1 is 01 in binary. Accordingly, this maps to
the color set {1}. A subindex of 2 (10 in binary) maps to the color set {2},
and a subindex of 3 (11 in binary) maps to the color set {1,2}.

Looking at the example output we can see that v2 touches one orbit in index 9.
This corresponds to orbit 3, with a subindex of 3. Therefore, v2 touches orbit
3, with the color set {1,2}. We can verify this by looking at our example
graph.
